@@ -1,8 +1,7 @@
 """
-Copyright 2019 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 SPDX-License-Identifier: MIT-0
 """
-import six
 from cfnlint.helpers import PSEUDOPARAMS
 from cfnlint.rules import CloudFormationLintRule
 from cfnlint.rules import RuleMatch
@@ -24,7 +23,7 @@ class RelationshipConditions(CloudFormationLintRule):
         matches = []
 
         # Start with Ref checks
-        ref_objs = cfn.search_deep_keys('Ref')
+        ref_objs = cfn.search_deep_keys(searchText='Ref', includeGlobals=False)
         for ref_obj in ref_objs:
             value = ref_obj[-1]
             if value not in PSEUDOPARAMS:
@@ -42,13 +41,13 @@ class RelationshipConditions(CloudFormationLintRule):
                                 '/'.join(map(str, ref_obj[:-1])))))
 
         # The do GetAtt
-        getatt_objs = cfn.search_deep_keys('Fn::GetAtt')
+        getatt_objs = cfn.search_deep_keys(searchText='Fn::GetAtt', includeGlobals=False)
         for getatt_obj in getatt_objs:
             value_obj = getatt_obj[-1]
             value = None
             if isinstance(value_obj, list):
                 value = value_obj[0]
-            elif isinstance(value_obj, six.string_types):
+            elif isinstance(value_obj, str):
                 value = value_obj.split('.')[0]
             if value:
                 if value not in PSEUDOPARAMS:
