@@ -10,7 +10,7 @@ class Select(CloudFormationLintRule):
     """Check if Select values are correct"""
     id = 'E1017'
     shortdesc = 'Select validation of parameters'
-    description = 'Making sure the function not is of list'
+    description = 'Making sure the Select function is properly configured'
     source_url = 'https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/intrinsic-function-reference-select.html'
     tags = ['functions', 'select']
 
